==> gromacs_2019.1.orig.tar.gz: gromacs-2019.1/cmake/gmxDetectTargetArchitecture.cmake <==
#
# This file is part of the GROMACS molecular simulation package.
#
# Copyright (c) 2013,2014,2016,2018, by the GROMACS development team, led by
# Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
# and including many others, as listed in the AUTHORS file in the
# top-level source directory and at http://www.gromacs.org.
#
# GROMACS is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# as published by the Free Software Foundation; either version 2.1
# of the License, or (at your option) any later version.
#
# GROMACS is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with GROMACS; if not, see
# http://www.gnu.org/licenses, or write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
#
# If you want to redistribute modifications to GROMACS, please
# consider that scientific software is very special. Version
# control is crucial - bugs must be traceable. We will be happy to
# consider code for inclusion in the official distribution, but
# derived work must not be called official GROMACS. Details are found
# in the README & COPYING files - if they are missing, get the
# official version at http://www.gromacs.org.
#
# To help us fund GROMACS development, we humbly ask that you cite
# the research papers on the package. Check out http://www.gromacs.org.

# - Define function to detect whether the compiler's target
# - architecture is one for which GROMACS has special treatment
#   (e.g. SIMD instructions)
#
# Sets GMX_TARGET_X86 etc. if targetting that architecture. May set
# other such variables if/when there is future need.

function(gmx_detect_target_architecture)
    if (NOT DEFINED GMX_TARGET_X86)
        try_compile(GMX_TARGET_X86 ${CMAKE_BINARY_DIR}
            "${CMAKE_SOURCE_DIR}/cmake/TestX86.c")
    endif()
    if (NOT DEFINED GMX_TARGET_MIC)
        try_compile(GMX_TARGET_MIC ${CMAKE_BINARY_DIR}
            "${CMAKE_SOURCE_DIR}/cmake/TestMIC.c")
    endif()
    if (NOT DEFINED GMX_TARGET_ARMV7)
        try_compile(GMX_TARGET_ARMV7 ${CMAKE_BINARY_DIR}
            "${CMAKE_SOURCE_DIR}/cmake/TestARMv7.cpp")
    endif()
    if (NOT DEFINED GMX_TARGET_FUJITSU_SPARC64)
        try_compile(GMX_TARGET_FUJITSU_SPARC64 ${CMAKE_BINARY_DIR}
            "${CMAKE_SOURCE_DIR}/cmake/TestFujitsuSparc64.c")
    endif()
endfunction()

==> gromacs_2020.1.orig.tar.gz: gromacs-2020.1/cmake/gmxDetectTargetArchitecture.cmake <==
#
# This file is part of the GROMACS molecular simulation package.
#
# Copyright (c) 2013,2014,2016,2018,2019, by the GROMACS development team, led by
# Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
# and including many others, as listed in the AUTHORS file in the
# top-level source directory and at http://www.gromacs.org.
#
# GROMACS is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public License
# as published by the Free Software Foundation; either version 2.1
# of the License, or (at your option) any later version.
#
# GROMACS is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with GROMACS; if not, see
# http://www.gnu.org/licenses, or write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
#
# If you want to redistribute modifications to GROMACS, please
# consider that scientific software is very special. Version
# control is crucial - bugs must be traceable. We will be happy to
# consider code for inclusion in the official distribution, but
# derived work must not be called official GROMACS. Details are found
# in the README & COPYING files - if they are missing, get the
# official version at http://www.gromacs.org.
#
# To help us fund GROMACS development, we humbly ask that you cite
# the research papers on the package. Check out http://www.gromacs.org.

# - Define function to detect whether the compiler's target
# - architecture is one for which GROMACS has special treatment
#   (e.g. SIMD instructions)
#
# Sets GMX_TARGET_X86 etc. if targetting that architecture. May set
# other such variables if/when there is future need.

function(gmx_detect_target_architecture)
    if (NOT DEFINED GMX_TARGET_X86)
        try_compile(GMX_TARGET_X86 ${CMAKE_BINARY_DIR}
            "${CMAKE_SOURCE_DIR}/cmake/TestX86.cpp")
    endif()
    if (NOT DEFINED GMX_TARGET_MIC)
        try_compile(GMX_TARGET_MIC ${CMAKE_BINARY_DIR}
            "${CMAKE_SOURCE_DIR}/cmake/TestMIC.cpp")
    endif()
    if (NOT DEFINED GMX_TARGET_ARMV7)
        try_compile(GMX_TARGET_ARMV7 ${CMAKE_BINARY_DIR}
            "${CMAKE_SOURCE_DIR}/cmake/TestARMv7.cpp")
    endif()
    if (NOT DEFINED GMX_TARGET_FUJITSU_SPARC64)
        try_compile(GMX_TARGET_FUJITSU_SPARC64 ${CMAKE_BINARY_DIR}
            "${CMAKE_SOURCE_DIR}/cmake/TestFujitsuSparc64.cpp")
    endif()
endfunction()
